@@ -1,5 +1,8 @@
 """Top-level package for Study Lyte ."""
 
 __author__ = """Micah Johnson """
-__email__ = 'audreyr@example.com'
-__version__ = '0.1.0'
+__email__ = 'info@adventuredata.com'
+__version__ = '0.3.0'
+
+
+
